torchelie.loss
==============

Functions
~~~~~~~~~

.. autofunction:: torchelie.loss.tempered_cross_entropy
.. autofunction:: torchelie.loss.tempered_nll_loss
.. autofunction:: torchelie.loss.tempered_softmax
.. autofunction:: torchelie.loss.tempered_log_softmax
.. autofunction:: torchelie.loss.ortho
.. autofunction:: torchelie.loss.total_variation
.. autofunction:: torchelie.loss.continuous_cross_entropy
.. autofunction:: torchelie.loss.focal_loss

Modules
~~~~~~~

.. autoclass:: torchelie.loss.TemperedCrossEntropyLoss
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.OrthoLoss
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.TotalVariationLoss
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.ContinuousCEWithLogits
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.FocalLoss
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.PerceptualLoss
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.NeuralStyleLoss
   :members:
   :undoc-members:
.. autoclass:: torchelie.loss.DeepDreamLoss
   :members:
   :undoc-members:

GAN losses
~~~~~~~~~~

.. automodule:: torchelie.loss.gan.hinge
   :members:
   :undoc-members:

.. automodule:: torchelie.loss.gan.standard
   :members:
   :undoc-members:
